@@ -118,7 +118,7 @@ LearnerRegrCVGlmnet = R6Class("LearnerRegrCVGlmnet",
 
     .predict = function(task) {
       pars = self$param_set$get_values(tags = "predict")
-      newdata = as.matrix(task$data(cols = task$feature_names))
+      newdata = as.matrix(ordered_features(task, glmnet_feature_names(self$model)))
 
       if (!is.null(pars$predict.gamma)) {
         pars$gamma = pars$predict.gamma
@@ -127,7 +127,7 @@ LearnerRegrCVGlmnet = R6Class("LearnerRegrCVGlmnet",
 
       response = invoke(stats::predict, self$model, newx = newdata,
         type = "response", .args = pars)
-      mlr3::PredictionRegr$new(task = task, response = drop(response))
+      list(response = drop(response))
     }
   )
 )
