@@ -122,7 +122,7 @@ LearnerRegrGlmnet = R6Class("LearnerRegrGlmnet",
 
     .predict = function(task) {
       pars = self$param_set$get_values(tags = "predict")
-      newdata = as.matrix(task$data(cols = task$feature_names))
+      newdata = as.matrix(ordered_features(task, glmnet_feature_names(self$model)))
 
       # only predict for one instance of 's' and not for 100
       if (is.null(pars$s)) {
@@ -132,7 +132,7 @@ LearnerRegrGlmnet = R6Class("LearnerRegrGlmnet",
       response = mlr3misc::invoke(stats::predict, self$model,
         newx = newdata,
         type = "response", .args = pars)
-      mlr3::PredictionRegr$new(task = task, response = drop(response))
+      list(response = drop(response))
     }
   )
 )
