@@ -65,12 +65,11 @@ LearnerRegrLM = R6Class("LearnerRegrLM",
       newdata = task$data(cols = task$feature_names)
 
       if (self$predict_type == "response") {
-        mlr3::PredictionRegr$new(task = task, response = stats::predict(self$model,
-          newdata = newdata,
-          se.fit = FALSE))
+        response = stats::predict(self$model, newdata = newdata, se.fit = FALSE)
+        list(response = response)
       } else {
         pred = stats::predict(self$model, newdata = newdata, se.fit = TRUE)
-        mlr3::PredictionRegr$new(task = task, response = pred$fit, se = pred$se.fit)
+        list(response = pred$fit, se = pred$se.fit)
       }
     }
   )
